<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QBluetoothDeviceDiscoveryAgent</name>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>Ungültige Bluetooth-Geräteadresse</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>Das Gerät unterstützt kein Bluetooth</translation>
    </message>
    <message>
        <source>Passed address is not a local device.</source>
        <translation>Übergebene Adresse gehört zu keinem lokalen Gerät.</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>Gerät ist ausgeschaltet</translation>
    </message>
    <message>
        <source>Input Output Error</source>
        <translation>Fehler bei Ein/Ausgabe</translation>
    </message>
    <message>
        <source>Bluetooth LE is not supported</source>
        <translation>Bluetooth LE wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Cannot start low energy device inquiry</source>
        <translation>Kann keine Bluetooth LE-Suche starten</translation>
    </message>
    <message>
        <source>Discovery cannot be started</source>
        <translation>Suche kann nicht gestartet werden</translation>
    </message>
    <message>
        <source>Discovery cannot be stopped</source>
        <translation>Suche kann nicht gestoppt werden</translation>
    </message>
    <message>
        <source>Cannot start device inquiry</source>
        <translation>Gerätesuche konnte nicht gestartet werden</translation>
    </message>
    <message>
        <source>Cannot find valid Bluetooth adapter.</source>
        <translation>Es konnte kein gültiger Bluetooth-Adapter gefunden werden.</translation>
    </message>
    <message>
        <source>Bluetooth adapter error</source>
        <translation>Fehler im Bluetooth-Adapter</translation>
    </message>
    <message>
        <source>Cannot access adapter during service discovery</source>
        <translation>Währen des Gerätesuchlaufes kann nicht auf den Adapter zugegriffen werden</translation>
    </message>
    <message>
        <source>Device discovery not supported on this platform</source>
        <translation>Gerätesuchlauf wird auf dieser Platform nicht unterstützt</translation>
    </message>
</context>
<context>
    <name>QBluetoothServiceDiscoveryAgent</name>
    <message>
        <source>Minimal service discovery failed</source>
        <translation>Minimal Service Discovery fehlgeschlagen</translation>
    </message>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>Ungültige Bluetooth-Geräteadresse</translation>
    </message>
    <message>
        <source>Platform does not support Bluetooth</source>
        <translation>Die Platform unterstützt kein Bluetooth</translation>
    </message>
    <message>
        <source>Android API below v15 does not support SDP discovery</source>
        <translation>SDP-Suche erfordert Android API Version 15 oder höher</translation>
    </message>
    <message>
        <source>Cannot create Android BluetoothDevice</source>
        <translation>Android Bluetooth-Gerät kann nicht erstellt werden</translation>
    </message>
    <message>
        <source>Cannot obtain service uuids</source>
        <translation>Ermittlung der Dienst-UUID fehlgeschlagen</translation>
    </message>
    <message>
        <source>Service Discovery</source>
        <translation>Dienstsuche</translation>
    </message>
    <message>
        <source>Serial Port Profile</source>
        <translation>Serialport-Profil</translation>
    </message>
    <message>
        <source>LAN Access Profile</source>
        <translation>LAN-Zugriff-Profil</translation>
    </message>
    <message>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <source>Object Push</source>
        <translation>Object Push</translation>
    </message>
    <message>
        <source>File Transfer</source>
        <translation>Dateiübertragung</translation>
    </message>
    <message>
        <source>Synchronization Command</source>
        <translation>Synchronisations-Steuerbefehl</translation>
    </message>
    <message>
        <source>Headset</source>
        <translation>Kopfhörer</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Target</source>
        <translation>Audio/Video Remote Control Target</translation>
    </message>
    <message>
        <source>Advanced Audio Distribution</source>
        <translation>Erweiterte Audio-Verteilung</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control</source>
        <translation>Audio/Video Remote Control</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Controller</source>
        <translation>Audio/Video Remote Control Controller</translation>
    </message>
    <message>
        <source>Headset AG</source>
        <translation>Kopfhörer (Audio Gateway)</translation>
    </message>
    <message>
        <source>Personal Area Networking (PANU)</source>
        <translation>Netzwerkzugang (PANU)</translation>
    </message>
    <message>
        <source>Personal Area Networking (NAP)</source>
        <translation>Netzwerkzugang (NAP)</translation>
    </message>
    <message>
        <source>Personal Area Networking (GN)</source>
        <translation>Netzwerkzugang (GN)</translation>
    </message>
    <message>
        <source>Browse Group Descriptor</source>
        <translation>Gruppenbeschreibung durchsuchen</translation>
    </message>
    <message>
        <source>Public Browse Group</source>
        <translation>Öffentliche Gruppe</translation>
    </message>
    <message>
        <source>Dial-Up Networking</source>
        <translation>Modemnetzwerk</translation>
    </message>
    <message>
        <source>Audio Source</source>
        <translation>Audioquelle</translation>
    </message>
    <message>
        <source>Audio Sink</source>
        <translation>Audioempfänger</translation>
    </message>
    <message>
        <source>Basic Direct Printing (BPP)</source>
        <translation>Druckfreigabe Basic Direct Printing (BPP)</translation>
    </message>
    <message>
        <source>Basic Reference Printing (BPP)</source>
        <translation>Druckfreigabe Basic Reference Printing (BPP)</translation>
    </message>
    <message>
        <source>Basic Imaging Profile</source>
        <translation>Einfaches Druckprofil</translation>
    </message>
    <message>
        <source>Basic Imaging Responder</source>
        <translation>Druckfreigabe (Responder)</translation>
    </message>
    <message>
        <source>Basic Imaging Archive</source>
        <translation>Druckfreigabe Archiv</translation>
    </message>
    <message>
        <source>Basic Imaging Ref Objects</source>
        <translation>Druckfreigabe (Ref Objects)</translation>
    </message>
    <message>
        <source>Hands-Free</source>
        <translation>Freisprechanlage</translation>
    </message>
    <message>
        <source>Hands-Free AG</source>
        <translation>Freisprechanlage AG</translation>
    </message>
    <message>
        <source>Basic Printing RefObject Service</source>
        <translation>Druckfreigabe (Ref Objects Service)</translation>
    </message>
    <message>
        <source>Basic Printing Reflected UI</source>
        <translation>Druckfreigabe UI</translation>
    </message>
    <message>
        <source>Basic Printing</source>
        <translation>Druckfreigabe</translation>
    </message>
    <message>
        <source>Basic Printing Status</source>
        <translation>Druckfreigabestatus</translation>
    </message>
    <message>
        <source>Human Interface Device</source>
        <translation>Mensch-Maschine-Schnittstelle</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement</source>
        <translation>Hardcopy Cable Replacement</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Print</source>
        <translation>Hardcopy Cable Replacement (Drucken)</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Scan</source>
        <translation>Hardcopy Cable Replacement (Scannen)</translation>
    </message>
    <message>
        <source>SIM Access Server</source>
        <translation>Server für SIM Zugriff</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System</source>
        <translation>Globales Satelliten-Navigationssystem</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System Server</source>
        <translation>Server für globales Satelliten-Navigationssystem</translation>
    </message>
    <message>
        <source>3D Synchronization Display</source>
        <translation>Synchronisation eines 3D-Displays</translation>
    </message>
    <message>
        <source>3D Synchronization Glasses</source>
        <translation>Synchronisation einer 3D-Brille</translation>
    </message>
    <message>
        <source>3D Synchronization</source>
        <translation>3D-Synchronisation</translation>
    </message>
    <message>
        <source>Multi-Profile Specification (Profile)</source>
        <translation>Multi-Profilspezifikation (Profil)</translation>
    </message>
    <message>
        <source>Multi-Profile Specification</source>
        <translation>Multi-Profilspezifikation</translation>
    </message>
    <message>
        <source>Device Identification</source>
        <translation>Geräteidentifikation</translation>
    </message>
    <message>
        <source>Generic Networking</source>
        <translation>Netzwerk allgemein</translation>
    </message>
    <message>
        <source>Generic File Transfer</source>
        <translation>Dateiübertragung</translation>
    </message>
    <message>
        <source>Generic Audio</source>
        <translation>Audio allgemein</translation>
    </message>
    <message>
        <source>Generic Telephony</source>
        <translation>Telefonie allgemein</translation>
    </message>
    <message>
        <source>Generic Access</source>
        <translation>Zugriff allgemein</translation>
    </message>
    <message>
        <source>Generic Attribute</source>
        <translation>Allgemeines Attribut</translation>
    </message>
    <message>
        <source>Immediate Alert</source>
        <translation>Sofortiger Alarm</translation>
    </message>
    <message>
        <source>Link Loss</source>
        <translation>Verbindungsverlust</translation>
    </message>
    <message>
        <source>Tx Power</source>
        <translation>Tx-Spannungsversorgung</translation>
    </message>
    <message>
        <source>Current Time Service</source>
        <translation>Zeitdienst</translation>
    </message>
    <message>
        <source>Reference Time Update Service</source>
        <translation>Referenzzeit-Aktualisierungsdienst</translation>
    </message>
    <message>
        <source>Next DST Change Service</source>
        <translation>Sommerzeit-Benachrichtigungsdienst</translation>
    </message>
    <message>
        <source>Glucose</source>
        <translation>Blutzucker</translation>
    </message>
    <message>
        <source>Health Thermometer</source>
        <translation>Fieberthermometer</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Geräteinformation</translation>
    </message>
    <message>
        <source>Heart Rate</source>
        <translation>Puls</translation>
    </message>
    <message>
        <source>Phone Alert Status Service</source>
        <translation>Telefon-Bereitschaftsdienst</translation>
    </message>
    <message>
        <source>Battery Service</source>
        <translation>Batteriestatusdienst</translation>
    </message>
    <message>
        <source>Blood Pressure</source>
        <translation>Blutdruck</translation>
    </message>
    <message>
        <source>Alert Notification Service</source>
        <translation>Alarmmeldungsdienst</translation>
    </message>
    <message>
        <source>Scan Parameters</source>
        <translation>Scan-Parameter</translation>
    </message>
    <message>
        <source>Cycling Power</source>
        <translation>Trittleistung</translation>
    </message>
    <message>
        <source>Location and Navigation</source>
        <translation>Ort und Navigation</translation>
    </message>
    <message>
        <source>Environmental Sensing</source>
        <translation>Umweltsensorik</translation>
    </message>
    <message>
        <source>Body Composition</source>
        <translation>Körperliche Verfassung</translation>
    </message>
    <message>
        <source>User Data</source>
        <translation>Nutzerdaten</translation>
    </message>
    <message>
        <source>Weight Scale</source>
        <translation>Gewichtsskala</translation>
    </message>
    <message>
        <source>Bond Management</source>
        <extracomment>Connection management (Bluetooth)</extracomment>
        <translation>Verbindungsverwaltung</translation>
    </message>
    <message>
        <source>Continuous Glucose Monitoring</source>
        <translation>Ständige Blutzuckermessung</translation>
    </message>
    <message>
        <source>Service Discovery Protocol</source>
        <translation>Service Discovery Protocol</translation>
    </message>
    <message>
        <source>User Datagram Protocol</source>
        <translation>User Datagram Protocol</translation>
    </message>
    <message>
        <source>Radio Frequency Communication</source>
        <translation>Radio Frequency Communication</translation>
    </message>
    <message>
        <source>Transmission Control Protocol</source>
        <translation>Transmission Control Protocol</translation>
    </message>
    <message>
        <source>Telephony Control Specification - Binary</source>
        <translation>Spezifikation der Telefonsteuerung - binär</translation>
    </message>
    <message>
        <source>Telephony Control Specification - AT</source>
        <translation>Spezifikation der Telefonsteuerung - AT</translation>
    </message>
    <message>
        <source>Attribute Protocol</source>
        <translation>Attribute Protocol</translation>
    </message>
    <message>
        <source>Object Exchange Protocol</source>
        <translation>Object Exchange Protocol</translation>
    </message>
    <message>
        <source>Internet Protocol</source>
        <translation>Internet Protocol</translation>
    </message>
    <message>
        <source>File Transfer Protocol</source>
        <translation>File Transfer Protocol</translation>
    </message>
    <message>
        <source>Hypertext Transfer Protocol</source>
        <translation>Hypertext Transfer Protocol</translation>
    </message>
    <message>
        <source>Wireless Short Packet Protocol</source>
        <translation>Wireless Short Packet Protocol</translation>
    </message>
    <message>
        <source>Bluetooth Network Encapsulation Protocol</source>
        <translation>Bluetooth Network Encapsulation Protocol</translation>
    </message>
    <message>
        <source>Extended Service Discovery Protocol</source>
        <translation>Extended Service Discovery Protocol</translation>
    </message>
    <message>
        <source>Human Interface Device Protocol</source>
        <translation>Human Interface Device Protocol</translation>
    </message>
    <message>
        <source>Hardcopy Control Channel</source>
        <translation>Druckkontrollkanal</translation>
    </message>
    <message>
        <source>Hardcopy Data Channel</source>
        <translation>Druckdatenkanal</translation>
    </message>
    <message>
        <source>Hardcopy Notification</source>
        <translation>Druckbenachrichtigung</translation>
    </message>
    <message>
        <source>Audio/Video Control Transport Protocol</source>
        <translation>Audio/Video Control Transport Protocol</translation>
    </message>
    <message>
        <source>Audio/Video Distribution Transport Protocol</source>
        <translation>Audio/Video Distribution Transport Protocol</translation>
    </message>
    <message>
        <source>Common ISDN Access Protocol</source>
        <translation>Common ISDN Access Protocol</translation>
    </message>
    <message>
        <source>UdiCPlain</source>
        <translation>UdiCPlain</translation>
    </message>
    <message>
        <source>Running Speed and Cadence</source>
        <translation>Schrittfrequenz und Lauftempo</translation>
    </message>
    <message>
        <source>Cycling Speed and Cadence</source>
        <translation>Trittfrequenz und Geschwindigkeit</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Data</source>
        <translation>Multi-Channel Adaptation Protocol - Data</translation>
    </message>
    <message>
        <source>Layer 2 Control Protocol</source>
        <translation>Layer 2 Control Protocol</translation>
    </message>
    <message>
        <source>GAP Device Name</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP-Gerätename</translation>
    </message>
    <message>
        <source>GAP Appearance</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP-Erscheinung</translation>
    </message>
    <message>
        <source>GAP Peripheral Privacy Flag</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP Peripheral Privacy Flag</translation>
    </message>
    <message>
        <source>GAP Reconnection Address</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>GAP Reconnection Address</translation>
    </message>
    <message>
        <source>GAP Peripheral Preferred Connection Parameters</source>
        <translation>GAP Peripheral Preferred Connection Parameters</translation>
    </message>
    <message>
        <source>GATT Service Changed</source>
        <extracomment>GATT: _G_eneric _Att_ribute Profile (Bluetooth)</extracomment>
        <translation>GATT Service Changed</translation>
    </message>
    <message>
        <source>Alert Level</source>
        <translation>Alarmzustand</translation>
    </message>
    <message>
        <source>TX Power</source>
        <translation>Tx-Spannungsversorgung</translation>
    </message>
    <message>
        <source>Date Time</source>
        <translation>Datum/Zeit</translation>
    </message>
    <message>
        <source>Day Of Week</source>
        <translation>Wochentag</translation>
    </message>
    <message>
        <source>Day Date Time</source>
        <translation>Tag Datum Zeit</translation>
    </message>
    <message>
        <source>Exact Time 256</source>
        <translation>Exakte Zeit 256</translation>
    </message>
    <message>
        <source>DST Offset</source>
        <translation>Sommerzeitverschiebung</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation>Zeitzone</translation>
    </message>
    <message>
        <source>Local Time Information</source>
        <translation>Information zur Ortszeit</translation>
    </message>
    <message>
        <source>Time With DST</source>
        <translation>Zeit unter Berücksichtigung der Sommerzeit</translation>
    </message>
    <message>
        <source>Time Accuracy</source>
        <translation>Genauigkeit der Zeitangabe</translation>
    </message>
    <message>
        <source>Time Source</source>
        <translation>Quelle der Zeitangabe</translation>
    </message>
    <message>
        <source>Reference Time Information</source>
        <translation>Referenzzeit-Information</translation>
    </message>
    <message>
        <source>Time Update Control Point</source>
        <translation>Kontrollpunkt Zeitaktualisierung</translation>
    </message>
    <message>
        <source>Time Update State</source>
        <translation>Status der Zeitaktualisierung</translation>
    </message>
    <message>
        <source>Glucose Measurement</source>
        <translation>Blutzuckermessung</translation>
    </message>
    <message>
        <source>Battery Level</source>
        <translation>Batteriestatus</translation>
    </message>
    <message>
        <source>Temperature Measurement</source>
        <translation>Temperaturmessung</translation>
    </message>
    <message>
        <source>Temperature Type</source>
        <translation>Typ der Temperatur</translation>
    </message>
    <message>
        <source>Intermediate Temperature</source>
        <translation>Zwischenzeitliche Temperatur</translation>
    </message>
    <message>
        <source>Measurement Interval</source>
        <translation>Messintervall</translation>
    </message>
    <message>
        <source>Boot Keyboard Input Report</source>
        <translation>Eingabemeldung von Boot-Tastatur</translation>
    </message>
    <message>
        <source>System ID</source>
        <translation>System-ID</translation>
    </message>
    <message>
        <source>Model Number String</source>
        <translation>Modellnummer als Zeichenkette</translation>
    </message>
    <message>
        <source>Serial Number String</source>
        <translation>Seriennummer als Zeichenkette</translation>
    </message>
    <message>
        <source>Firmware Revision String</source>
        <translation>Firmware-Revision als Zeichenkette</translation>
    </message>
    <message>
        <source>Hardware Revision String</source>
        <translation>Hardware-Revision als Zeichenkette</translation>
    </message>
    <message>
        <source>Software Revision String</source>
        <translation>Software-Revision als Zeichenkette</translation>
    </message>
    <message>
        <source>Manufacturer Name String</source>
        <translation>Herstellername als Zeichenkette</translation>
    </message>
    <message>
        <source>IEEE 11073 20601 Regulatory Certification Data List</source>
        <translation>IEEE 11073 20601 Regulatory Certification Data List</translation>
    </message>
    <message>
        <source>Current Time</source>
        <translation>Aktuelle Zeit</translation>
    </message>
    <message>
        <source>Scan Refresh</source>
        <translation>Scan erneut durchführen</translation>
    </message>
    <message>
        <source>Boot Keyboard Output Report</source>
        <translation>Ausgabemeldung von Boot-Tastatur</translation>
    </message>
    <message>
        <source>Boot Mouse Input Report</source>
        <translation>Eingabemeldung von Boot-Maus</translation>
    </message>
    <message>
        <source>Glucose Measurement Context</source>
        <translation>Kontext der Blutzuckermessung</translation>
    </message>
    <message>
        <source>Blood Pressure Measurement</source>
        <translation>Blutdruckmessung</translation>
    </message>
    <message>
        <source>Intermediate Cuff Pressure</source>
        <translation>Zwischenzeitlicher Druck der Manschette</translation>
    </message>
    <message>
        <source>Heart Rate Measurement</source>
        <translation>Pulsmessung</translation>
    </message>
    <message>
        <source>Body Sensor Location</source>
        <translation>Lage des Körpersensors</translation>
    </message>
    <message>
        <source>Heart Rate Control Point</source>
        <translation>Pulsabnahmepunkt</translation>
    </message>
    <message>
        <source>Alert Status</source>
        <translation>Status Alarmbereitschaft</translation>
    </message>
    <message>
        <source>Ringer Control Point</source>
        <translation>Kontrollpunkt des Signalgebers</translation>
    </message>
    <message>
        <source>Ringer Setting</source>
        <translation>Signalgebereinstellung</translation>
    </message>
    <message>
        <source>Alert Category ID Bit Mask</source>
        <translation>Bitmaske der Kategorie-ID (Alarmbereitschaft)</translation>
    </message>
    <message>
        <source>Alert Category ID</source>
        <translation>Kategorie-ID der Alarmbereitschaft</translation>
    </message>
    <message>
        <source>Alert Notification Control Point</source>
        <translation>Kontrollpunkt Alarmmeldung</translation>
    </message>
    <message>
        <source>Unread Alert Status</source>
        <translation>Status unbehandelter Alarmmeldungen</translation>
    </message>
    <message>
        <source>New Alert</source>
        <translation>Neue Alarmmeldung</translation>
    </message>
    <message>
        <source>Supported New Alert Category</source>
        <translation>Unterstützte neue Kategorie Alarmmeldungen</translation>
    </message>
    <message>
        <source>Supported Unread Alert Category</source>
        <translation>Unterstützte neue Kategorie unbehandelter Alarmmeldungen</translation>
    </message>
    <message>
        <source>Blood Pressure Feature</source>
        <translation>Blutdruck-Funktion</translation>
    </message>
    <message>
        <source>HID Information</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>HID-Information</translation>
    </message>
    <message>
        <source>Report Map</source>
        <translation>Übersicht der Berichte</translation>
    </message>
    <message>
        <source>HID Control Point</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>HID-Kontrollpunkt</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Bericht</translation>
    </message>
    <message>
        <source>Protocol Mode</source>
        <translation>Protokoll-Modus</translation>
    </message>
    <message>
        <source>Scan Interval Window</source>
        <translation>Scan-Intervallfenster</translation>
    </message>
    <message>
        <source>PnP ID</source>
        <translation>PnP-ID</translation>
    </message>
    <message>
        <source>Glucose Feature</source>
        <translation>Blutzucker-Funktion</translation>
    </message>
    <message>
        <source>Record Access Control Point</source>
        <extracomment>Glucose Sensor patient record database.</extracomment>
        <translation>Record Access Control Point</translation>
    </message>
    <message>
        <source>RSC Measurement</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>RSC-Messung</translation>
    </message>
    <message>
        <source>RSC Feature</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>RSC-Funktion</translation>
    </message>
    <message>
        <source>SC Control Point</source>
        <translation>SC-Kontrollpunkt</translation>
    </message>
    <message>
        <source>CSC Measurement</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>CSC-Messung</translation>
    </message>
    <message>
        <source>CSC Feature</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>CSC-Funktion</translation>
    </message>
    <message>
        <source>Sensor Location</source>
        <translation>Lage des Sensors</translation>
    </message>
    <message>
        <source>Cycling Power Measurement</source>
        <translation>Messung der Trittleistung</translation>
    </message>
    <message>
        <source>Cycling Power Vector</source>
        <translation>Vektor der Trittleistung</translation>
    </message>
    <message>
        <source>Cycling Power Feature</source>
        <translation>Trittleistungs-Funktion</translation>
    </message>
    <message>
        <source>Cycling Power Control Point</source>
        <translation>Kontrollpunkt Trittleistung</translation>
    </message>
    <message>
        <source>Magnetic Declination</source>
        <extracomment>Angle between geographic and magnetic north</extracomment>
        <translation>Magnetische Deklination</translation>
    </message>
    <message>
        <source>Elevation</source>
        <extracomment>Above/below sea level</extracomment>
        <translation>Höhe relativ zum Meerespiegel</translation>
    </message>
    <message>
        <source>True Wind Speed</source>
        <extracomment>Wind speed while standing</extracomment>
        <translation>Wahre Windgeschwindigkeit</translation>
    </message>
    <message>
        <source>Apparent Wind Speed</source>
        <extracomment>Wind speed while observer is moving</extracomment>
        <translation>Scheinbare Windgeschwindigkeit</translation>
    </message>
    <message>
        <source>Gust Factor</source>
        <extracomment>Factor by which wind gust is stronger than average wind</extracomment>
        <translation>Böenfaktor</translation>
    </message>
    <message>
        <source>Descriptor Value Changed</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>Wertänderung des Deskriptors</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Age of person</extracomment>
        <translation>Alter</translation>
    </message>
    <message>
        <source>Height</source>
        <extracomment>Height of a person</extracomment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Database Change Increment</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>Database Change Increment</translation>
    </message>
    <message>
        <source>Server Characteristic Configuration</source>
        <translation>Charakteristische Konfiguration des Servers</translation>
    </message>
    <message>
        <source>Location And Speed</source>
        <translation>Ort und Geschwindigkeit</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Control</source>
        <translation>Multi-Channel Adaptation Protocol - Control</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <source>Position Quality</source>
        <translation>Güte der Ortsdaten</translation>
    </message>
    <message>
        <source>LN Feature</source>
        <translation>LN-Funktion</translation>
    </message>
    <message>
        <source>LN Control Point</source>
        <translation>LN-Kontrollpunkt</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Druck</translation>
    </message>
    <message>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Luftfeuchtigkeit</translation>
    </message>
    <message>
        <source>True Wind Direction</source>
        <translation>Wahre Windrichtung</translation>
    </message>
    <message>
        <source>Apparent Wind Direction</source>
        <translation>Scheinbare Windrichtung</translation>
    </message>
    <message>
        <source>Pollen Concentration</source>
        <translation>Pollenkonzentration</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV-Index</translation>
    </message>
    <message>
        <source>Irradiance</source>
        <translation>Strahlungsintensität</translation>
    </message>
    <message>
        <source>Rainfall</source>
        <translation>Regen</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Windkühle</translation>
    </message>
    <message>
        <source>Heat Index</source>
        <translation>Hitzeindex</translation>
    </message>
    <message>
        <source>Dew Point</source>
        <translation>Taupunkt</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Lower Limit</source>
        <translation>Aerober minimaler Puls</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Upper Limit</source>
        <translation>Aerober maximaler Puls</translation>
    </message>
    <message>
        <source>Aerobic Threshold</source>
        <translation>Aerobe Schwelle</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Lower Limit</source>
        <translation>Anaerober minimaler Puls</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Upper Limit</source>
        <translation>Anaerober maximaler Puls</translation>
    </message>
    <message>
        <source>Anaerobic Threshold</source>
        <translation>Anaerobe Schwelle</translation>
    </message>
    <message>
        <source>Date Of Birth</source>
        <translation>Geburtsdatum</translation>
    </message>
    <message>
        <source>Date Of Threshold Assessment</source>
        <translation>Datum der Schwellenbestimmung</translation>
    </message>
    <message>
        <source>Email Address</source>
        <translation>E-Mail-Adresse</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Lower Limit</source>
        <translation>Minimaler Puls, bei dem Fettverbrennung stattfindet</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Upper Limit</source>
        <translation>Maximaler Puls, bei dem Fettverbrennung stattfindet</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>5-Zone Heart Rate Limits</source>
        <translation>Pulslimits / 5 Zonen</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <source>Heart Rate Maximum</source>
        <translation>Maximaler Puls</translation>
    </message>
    <message>
        <source>Hip Circumference</source>
        <translation>Hüftumfang</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Maximum Recommended Heart Rate</source>
        <translation>Maximaler empfohlener Puls</translation>
    </message>
    <message>
        <source>Resting Heart Rate</source>
        <translation>Ruhepuls</translation>
    </message>
    <message>
        <source>Sport Type For Aerobic/Anaerobic Thresholds</source>
        <translation>Sportart für Aerobe/Anaerobe Schwellen</translation>
    </message>
    <message>
        <source>3-Zone Heart Rate Limits</source>
        <translation>Pulslimits / 3 Zonen</translation>
    </message>
    <message>
        <source>2-Zone Heart Rate Limits</source>
        <translation>Pulslimits / 2 Zonen</translation>
    </message>
    <message>
        <source>Oxygen Uptake</source>
        <translation>Sauerstoffaufnahme</translation>
    </message>
    <message>
        <source>Waist Circumference</source>
        <translation>Taillenumfang</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <source>User Index</source>
        <translation>Nutzerindex</translation>
    </message>
    <message>
        <source>Body Composition Feature</source>
        <translation>Funktion für Körperliche Verfassung</translation>
    </message>
    <message>
        <source>Body Composition Measurement</source>
        <translation>Muskelanteilmessung</translation>
    </message>
    <message>
        <source>Weight Measurement</source>
        <translation>Gewichtsmessung</translation>
    </message>
    <message>
        <source>User Control Point</source>
        <translation>Nutzerkontrollpunkt</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 2D</source>
        <translation>Magnetische Flussdichte 2D</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 3D</source>
        <translation>Magnetische Flussdichte 3D</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Barometric Pressure Trend</source>
        <translation>Trend des barometrischen Drucks</translation>
    </message>
    <message>
        <source>Characteristic Extended Properties</source>
        <translation>Charakteristische erweiterte Eigenschaften</translation>
    </message>
    <message>
        <source>Characteristic User Description</source>
        <translation>Charakteristische Nutzerbeschreibung</translation>
    </message>
    <message>
        <source>Client Characteristic Configuration</source>
        <translation>Charakteristische Konfiguration des Clients</translation>
    </message>
    <message>
        <source>Characteristic Presentation Format</source>
        <translation>Charakteristisches Darstellungsformat</translation>
    </message>
    <message>
        <source>Characteristic Aggregate Format</source>
        <translation>Charakteristisches Format zusammengesetzter Typen</translation>
    </message>
    <message>
        <source>Valid Range</source>
        <translation>Gültigkeitsbereich</translation>
    </message>
    <message>
        <source>External Report Reference</source>
        <translation>Referenz zu externem Bericht</translation>
    </message>
    <message>
        <source>Report Reference</source>
        <translation>Referenz zu Bericht</translation>
    </message>
    <message>
        <source>Environmental Sensing Configuration</source>
        <translation>Konfiguration der Umgebungssensoren</translation>
    </message>
    <message>
        <source>Environmental Sensing Measurement</source>
        <translation>Messung der Umgebung</translation>
    </message>
    <message>
        <source>Environmental Sensing Trigger Setting</source>
        <translation>Einstellung der Trigger der Umgebungssensoren</translation>
    </message>
    <message>
        <source>Phonebook Access PCE</source>
        <translation>Telefonbuchzugang (Client)</translation>
    </message>
    <message>
        <source>Phonebook Access PSE</source>
        <translation>Telefonbuchzugang (Server)</translation>
    </message>
    <message>
        <source>Phonebook Access</source>
        <translation>Telefonbuchzugang</translation>
    </message>
    <message>
        <source>Headset HS</source>
        <translation>Kopfhörer (HS)</translation>
    </message>
    <message>
        <source>Message Access Server</source>
        <translation>Nachrichten-Zugangsserver</translation>
    </message>
    <message>
        <source>Message Notification Server</source>
        <translation>Nachrichten-Benachrichtigungs-Server</translation>
    </message>
    <message>
        <source>Message Access</source>
        <translation>Nachrichtenzugang</translation>
    </message>
    <message>
        <source>Video Source</source>
        <translation>Videoquelle</translation>
    </message>
    <message>
        <source>Video Sink</source>
        <translation>Videosenke</translation>
    </message>
    <message>
        <source>Video Distribution</source>
        <translation>Videoverteilung</translation>
    </message>
    <message>
        <source>Health Device</source>
        <translation>Medizinisches Gerät</translation>
    </message>
    <message>
        <source>Health Device Source</source>
        <translation>Medizinisches Gerät (Quelle)</translation>
    </message>
    <message>
        <source>Health Device Sink</source>
        <translation>Medizinisches Gerät (Senke)</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>Gerät ist ausgeschaltet</translation>
    </message>
    <message>
        <source>Unable to find appointed local adapter</source>
        <translation>Angegebene Geräteadresse konnte nicht als lokales Gerät identifiziert werden</translation>
    </message>
    <message>
        <source>Cannot find local Bluetooth adapter</source>
        <translation>Es konnte kein lokaler Bluetooth-Adapter gefunden werden</translation>
    </message>
    <message>
        <source>Local device is powered off</source>
        <translation>Das lokale Gerät ist ausgeschaltet</translation>
    </message>
    <message>
        <source>Unable to find sdpscanner</source>
        <translation>Es kann kein sdpscanner gefunden werden</translation>
    </message>
    <message>
        <source>Unable to perform SDP scan</source>
        <translation>Es kann kein SDP-Scan durchgeführt werden</translation>
    </message>
    <message>
        <source>Unable to access device</source>
        <translation>Zugriff auf Gerät nicht möglich</translation>
    </message>
    <message>
        <source>Custom Service</source>
        <translation>Benutzerdefinierter Dienst</translation>
    </message>
    <message>
        <source>Unknown Service</source>
        <translation>Unbekannter Dienst</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocket</name>
    <message>
        <source>Trying to connect while connection is in progress</source>
        <translation>Versuch der Verbindungsaufnahme für bereits aktiven Socket</translation>
    </message>
    <message>
        <source>Socket type not supported</source>
        <translation>Sockettyp wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Unknown socket error</source>
        <translation>Unbekannter Socket-Fehler</translation>
    </message>
    <message>
        <source>Connecting to port is not supported</source>
        <translation>Verbindungsaufbau mittels eines Ports wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Service cannot be found</source>
        <translation>Dienst konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Invalid data/data size</source>
        <translation>Ungültige Daten/Datengröße</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>Das Gerät unterstützt kein Bluetooth</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>Gerät ist ausgeschaltet</translation>
    </message>
    <message>
        <source>Cannot access address %1</source>
        <comment>%1 = Bt address e.g. 11:22:33:44:55:66</comment>
        <translation>Fehler beim Zugriff auf %1</translation>
    </message>
    <message>
        <source>Cannot connect to %1 on %2</source>
        <comment>%1 = uuid, %2 = Bt address</comment>
        <translation>Fehler beim Verbindungsaufbau zu %1 (%2)</translation>
    </message>
    <message>
        <source>Connection to service failed</source>
        <translation>Verbindungsaufbau zum Dienst fehlgeschlagen</translation>
    </message>
    <message>
        <source>Obtaining streams for service failed</source>
        <translation>Öffnen der Eingabe- und Ausgabestreams des Dienstes fehlgeschlagen</translation>
    </message>
    <message>
        <source>Input stream thread cannot be started</source>
        <translation>Thread des Eingabestreams konnte nicht gestartet werden</translation>
    </message>
    <message>
        <source>Cannot write while not connected</source>
        <translation>Schreibvorgang wegen fehlender Verbindung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Error during write on socket.</source>
        <translation>Fehler beim Schreibzugriff auf den Socket aufgetreten.</translation>
    </message>
    <message>
        <source>Network error during read</source>
        <translation>Netzwerkfehler während des Lesevorgangs</translation>
    </message>
    <message>
        <source>Network Error</source>
        <translation>Netzwerkfehler</translation>
    </message>
    <message>
        <source>Cannot read while not connected</source>
        <translation>Lesevorgang wegen fehlender Verbindung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Cannot set connection security level</source>
        <translation>Die Sicherheitsstufe der Verbindung konnte nicht eingestellt werden</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReply</name>
    <message>
        <source>Invalid input device (null)</source>
        <translation>Ungültiges Eingabegerät (null)</translation>
    </message>
    <message>
        <source>QIODevice cannot be read. Make sure it is open for reading.</source>
        <translation>Es konnte nicht vom QIODevice gelesen werden. Stellen Sie sicher, dass es zum Lesen geöffnet ist.</translation>
    </message>
    <message>
        <source>Push session cannot connect</source>
        <translation>Push-Session konnte keine Verbindung erhalten</translation>
    </message>
    <message>
        <source>Source file does not exist</source>
        <translation>Quelldatei existiert nicht</translation>
    </message>
    <message>
        <source>Push session failed</source>
        <translation>Push-Session fehlgeschlagen</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation>Operation abgebrochen</translation>
    </message>
    <message>
        <source>Transfer already started</source>
        <translation>Übertragung wurde bereits begonnen</translation>
    </message>
    <message>
        <source>Push service not found</source>
        <translation>Push Service konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Invalid target address</source>
        <translation>Ungültige Zieladresse</translation>
    </message>
    <message>
        <source>Push session cannot be started</source>
        <translation>Push-Session konnte nicht gestartet werden</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReplyBluez</name>
    <message>
        <source>Unknown Error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Could not open file for sending</source>
        <translation>Datei konnte nicht zum Senden geöffnet werden</translation>
    </message>
    <message>
        <source>The transfer was canceled</source>
        <translation>Die Übertragung wurde abgebrochen</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation>Operation abgebrochen</translation>
    </message>
</context>
<context>
    <name>QLowEnergyController</name>
    <message>
        <source>Remote device cannot be found</source>
        <translation>Gegenseite konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Cannot find local adapter</source>
        <translation>Es konnte kein lokaler Adapter gefunden werden</translation>
    </message>
    <message>
        <source>Error occurred during connection I/O</source>
        <translation>Fehler bei Ein/Ausgabe auf der Verbindung</translation>
    </message>
    <message>
        <source>Unknown Error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Error occurred trying to connect to remote device.</source>
        <translation>Beim Aufbau der Verbindung zum Gerät trat ein Fehler auf.</translation>
    </message>
</context>
</TS>
